is.chisq <-
function(x,m,a=10,n0=NULL)
{
	re=1;
	for(i in 1:length(x))
		if(x[i]<0)
			re=-1;
	p=rep(0,m+2);
	y=rep(0,m+2);
	q=0;
	if(re==-1)
	{
		return(data.frame("state"=-1,"pvalue"=1));
	}
	else
	{
		if(is.null(n0))
		{
			n0=mean(x);
			df=m-1;
		}
		else
		{
			df=m;
		}
		if(n0>0)
		{
		di=max(x)-min(x);
		for(i in 1:m)
		{
			p[i]=pchisq(min(x)+di*i/m,n0)-pchisq(min(x)+di*(i-1)/m,n0);
			if(p[i]==0)
			{
				break;
			}
			for(j in 1:length(x))
				if(x[j]>(min(x)+di*(i-1)/m) && x[j]<=(min(x)+di*i/m))
					y[i]=y[i]+1;
			q=q+(y[i]-(length(x)*p[i]))^2/(length(x)*p[i]);
		}
		p[m+1]=pchisq(Inf,n0)-pchisq(max(x),n0)
		y[m+1]=0
		p[m+2]=pchisq(min(x),n0);
		y[m+2]=length(which(x==min(x)));
                             if(p[m+1]!=0)
			q=q+(y[m+1]-(length(x)*p[m+1]))^2/(length(x)*p[m+1]);
		if(p[m+2]!=0)
			q=q+(y[m+2]-(length(x)*p[m+2]))^2/(length(x)*p[m+2]);
		q0=qchisq(1-a,df);
                pvalue=pchisq(q,df);
		if(q<=q0)
		{
			return(data.frame("qchisq"=q,"pvalue"=pvalue));
		}
		else
		{
			return(data.frame("state"=-1,"pvalue"=1));
		}
		}
		else
		{
			return(data.frame("state"=-1,"pvalue"=1));
		}
	}
}
